@@ -1,4 +1,5 @@
 import numpy as np
+from ..decorator import check_vector
 
 class MAE:
   def predict(self, y_predict, y):
@@ -9,11 +10,13 @@ class MAE:
     return 'mae'
 
 class MSE:
+  @check_vector
   def predict(self, y_predict, y):
     result = np.square(y_predict - y)
     result = np.mean(result)
     return result
 
+  @check_vector
   def d(self, y_predict, y):
     diff = y_predict - y
     shape = diff.shape
@@ -27,6 +30,7 @@ class MSE:
     return 'mse'
 
 class BINARY_CROSS_ENTROPY:
+  @check_vector
   def predict(self, y_predict, y):
     H = self.get_H(y_predict, y)
     result = np.mean(H)
@@ -48,6 +52,7 @@ class BINARY_CROSS_ENTROPY:
   def get_H(self, X, z):
     return self.relu(X) - X * z + np.log(1 + np.exp(-np.abs(X)))
   
+  @check_vector
   def d(self, y_predict, y):
     result = 1.0 / np.prod(y_predict.shape)
     result = result * self.derv_H_sigmoid(y_predict, y)    
@@ -58,6 +63,7 @@ class BINARY_CROSS_ENTROPY:
     return 'BINARY_CROSS_ENTROPY'
 
 class ACCURACY:
+  @check_vector
   def predict(self, y_predict, y):
     est_yes = np.greater(y_predict, 0)
     ans_yes = np.greater(y, 0.5)
@@ -82,6 +88,7 @@ class ACCURACY:
 
 
 class PRECISION:
+  @check_vector
   def predict(self, y_predict, y):
     est_yes = np.greater(y_predict, 0)
     ans_yes = np.greater(y, 0.5)
@@ -105,6 +112,7 @@ class PRECISION:
     return 'PRECISION'
 
 class RECALL:
+  @check_vector
   def predict(self, y_predict, y):
     est_yes = np.greater(y_predict, 0)
     ans_yes = np.greater(y, 0.5)
@@ -128,6 +136,7 @@ class RECALL:
     return 'RECALL'
 
 class F1:
+  @check_vector
   def predict(self, y_predict, y):
     est_yes = np.greater(y_predict, 0)
     ans_yes = np.greater(y, 0.5)
